@@ -19,15 +19,24 @@ knitr::include_graphics("figures/whole_model_test.png")
 ## ----echo=FALSE, out.width='100%', fig.cap="Whole Model Test Results for Example 2"----
 knitr::include_graphics("figures/whole_model_2.png")
 
-## ----echo=FALSE, out.width='100%', fig.cap="LRMSE for {debias}x{objective}"----
-knitr::include_graphics("figures/lrmse.png")
+## ----show-file4, echo=FALSE, results='asis'-----------------------------------
+raw_file3 <- readLines("debias_and_objective.R")
+cat("```r\n")
+cat(raw_file3, sep="\n")
+cat("\n```\n")
 
-## ----echo=FALSE, out.width='100%', fig.cap="Paired LRMSE for {debias}x{objective}"----
-knitr::include_graphics("figures/paired_lrmse.png")
+## ----echo=FALSE, out.width='100%', fig.cap="Simulation-blocked Residual LRMSE for different objective functions and debiasing"----
+knitr::include_graphics("figures/14AUG25.png")
 
-## ----echo=FALSE, out.width='100%', fig.cap="LRMSE for different weight_scheme"----
-knitr::include_graphics("figures/lrmse_identity.png")
+## ----show-file5, echo=FALSE, results='asis'-----------------------------------
+raw_file4 <- readLines("svem_vs_lassoCV_par_v2.R")
+cat("```r\n")
+cat(raw_file4, sep="\n")
+cat("\n```\n")
 
-## ----echo=FALSE, out.width='100%', fig.cap="Residual LRMSE for different weight_scheme"----
-knitr::include_graphics("figures/paired_lmrse_identity.png")
+## ----show-file6, echo=FALSE, results='asis'-----------------------------------
+raw_file6 <- readLines("debias_aicc_cvglm.R")
+cat("```r\n")
+cat(raw_file6, sep="\n")
+cat("\n```\n")
 
